@@ -21,14 +21,13 @@
 #define INCREMENTALSEARCHBAR_H
 
 // Qt
-#include <QWidget>
+#include <QtGui/QWidget>
 #include <QtCore/QBitArray>
 
 class QAction;
 class QLabel;
 class QTimer;
 class KLineEdit;
-class QToolButton;
 
 namespace Konsole
 {
@@ -67,9 +66,7 @@ public:
         /** Searches are case-sensitive or not */
         MatchCase        = 1,
         /** Searches use regular expressions */
-        RegExp           = 2,
-        /** Search from the bottom and up **/
-        ReverseSearch = 3
+        RegExp           = 2
     };
 
     /**
@@ -96,10 +93,6 @@ public:
     /** Returns the current search text */
     QString searchText();
 
-    void setSearchText(const QString& text);
-
-    void focusLineEdit();
-
     // reimplemented
     virtual void setVisible(bool visible);
 signals:
@@ -109,8 +102,6 @@ signals:
     void findNextClicked();
     /** Emitted when the user clicks the button to find the previous match */
     void findPreviousClicked();
-    /** The search from beginning/end button */
-    void searchFromClicked();
     /**
      * Emitted when the user toggles the checkbox to indicate whether
      * matches for the search text should be highlighted
@@ -128,33 +119,21 @@ signals:
     void matchRegExpToggled(bool);
     /** Emitted when the close button is clicked */
     void closeClicked();
-    /** Emitted when the return button is pressed in the search box */
-    void searchReturnPressed(const QString& text);
-    /** Emitted when shift+return buttons are pressed in the search box */
-    void searchShiftPlusReturnPressed();
-    /** A movement key not handled is forwarded to the terminal display */
-    void unhandledMovementKeyPressed(QKeyEvent *event);
 
 protected:
     virtual bool eventFilter(QObject* watched , QEvent* event);
-    virtual void keyPressEvent(QKeyEvent* event);
-
-public slots:
-    void clearLineEdit();
 
 private slots:
     void notifySearchChanged();
-    void updateButtonsAccordingToReverseSearchSetting();
+    void clearLineEdit();
 
 private:
+    bool _foundMatch;
+
     KLineEdit* _searchEdit;
     QAction* _caseSensitive;
     QAction* _regExpression;
     QAction* _highlightMatches;
-    QAction* _reverseSearch;
-    QToolButton* _findNextButton;
-    QToolButton* _findPreviousButton;
-    QToolButton* _searchFromButton;
 
     QTimer* _searchTimer;
 };
