@@ -25,9 +25,8 @@
 // Qt
 #include <QtCore/QHash>
 #include <QtCore/QList>
-#include <QtGui/QKeySequence>
+//#include <QtGui/QKeySequence>
 #include <QtCore/QMetaType>
-#include <QtCore/QVarLengthArray>
 
 // Konsole
 #include "konsole_export.h"
@@ -37,7 +36,6 @@ class QTextStream;
 
 namespace Konsole
 {
-
 /**
  * A convertor which maps between key sequences pressed by the user and the
  * character strings which should be sent to the terminal and commands
@@ -59,11 +57,10 @@ public:
      * the terminal emulation is in.  Therefore findEntry() may return a different
      * Entry depending upon the state flags supplied.
      *
-     * This enum describes the states which may be associated with with a particular
+     * This enum describes the states which may be associated with a particular
      * entry in the keyboard translation entry.
      */
-    enum State
-    {
+    enum State {
         /** Indicates that no special state is active */
         NoState = 0,
         /**
@@ -89,13 +86,12 @@ public:
         /** Indicates that the numpad is in application mode. */
         ApplicationKeypadState = 32
     };
-    Q_DECLARE_FLAGS(States,State)
+    Q_DECLARE_FLAGS(States, State)
 
     /**
      * This enum describes commands which are associated with particular key sequences.
      */
-    enum Command
-    {
+    enum Command {
         /** Indicates that no command is associated with this command sequence */
         NoCommand = 0,
         /** TODO Document me */
@@ -112,12 +108,10 @@ public:
         ScrollUpToTopCommand = 32,
         /** Scroll the terminal display down to the end of history */
         ScrollDownToBottomCommand = 64,
-        /** Toggles scroll lock mode */
-        ScrollLockCommand = 128,
         /** Echos the operating system specific erase character. */
         EraseCommand = 256
     };
-    Q_DECLARE_FLAGS(Commands,Command)
+    Q_DECLARE_FLAGS(Commands, Command)
 
     /**
      * Represents an association between a key sequence pressed by the user
@@ -141,7 +135,7 @@ public:
         /** Returns the commands associated with this entry */
         Command command() const;
         /** Sets the command associated with this entry. */
-        void setCommand(Command command);
+        void setCommand(Command aCommand);
 
         /**
          * Returns the character sequence associated with this entry, optionally replacing
@@ -153,13 +147,13 @@ public:
          * @param expandWildCards Specifies whether wild cards (occurrences of the '*' character) in
          * the entry should be replaced with a number to indicate the modifier keys being pressed.
          *
-         * @param modifiers The keyboard modifiers being pressed.
+         * @param keyboardModifiers The keyboard modifiers being pressed.
          */
         QByteArray text(bool expandWildCards = false,
-                        Qt::KeyboardModifiers modifiers = Qt::NoModifier) const;
+                        Qt::KeyboardModifiers keyboardModifiers = Qt::NoModifier) const;
 
         /** Sets the character sequence associated with this entry */
-        void setText(const QByteArray& text);
+        void setText(const QByteArray& aText);
 
         /**
          * Returns the character sequence associated with this entry,
@@ -176,7 +170,7 @@ public:
         /** Returns the character code ( from the Qt::Key enum ) associated with this entry */
         int keyCode() const;
         /** Sets the character code associated with this entry */
-        void setKeyCode(int keyCode);
+        void setKeyCode(int aKeyCode);
 
         /**
          * Returns a bitwise-OR of the enabled keyboard modifiers associated with this entry.
@@ -192,9 +186,9 @@ public:
         Qt::KeyboardModifiers modifierMask() const;
 
         /** See modifiers() */
-        void setModifiers( Qt::KeyboardModifiers modifiers );
+        void setModifiers(Qt::KeyboardModifiers modifiers);
         /** See modifierMask() and modifiers() */
-        void setModifierMask( Qt::KeyboardModifiers modifiers );
+        void setModifierMask(Qt::KeyboardModifiers modifiers);
 
         /**
          * Returns a bitwise-OR of the enabled state flags associated with this entry.
@@ -210,9 +204,9 @@ public:
         States stateMask() const;
 
         /** See state() */
-        void setState( States state );
+        void setState(States aState);
         /** See stateMask() */
-        void setStateMask( States mask );
+        void setStateMask(States aStateMask);
 
         /**
          * Returns the key code and modifiers associated with this entry
@@ -240,15 +234,15 @@ public:
          * Returns true if this entry matches the given key sequence, specified
          * as a combination of @p keyCode , @p modifiers and @p state.
          */
-        bool matches( int keyCode , 
-                      Qt::KeyboardModifiers modifiers , 
-                      States flags ) const;
+        bool matches(int keyCode ,
+                     Qt::KeyboardModifiers modifiers ,
+                     States flags) const;
 
         bool operator==(const Entry& rhs) const;
 
     private:
-        void insertModifier( QString& item , int modifier ) const;
-        void insertState( QString& item , int state ) const;
+        void insertModifier(QString& item , int modifier) const;
+        void insertState(QString& item , int state) const;
         QByteArray unescape(const QByteArray& text) const;
 
         int _keyCode;
@@ -262,7 +256,7 @@ public:
     };
 
     /** Constructs a new keyboard translator with the given @p name */
-    KeyboardTranslator(const QString& name);
+    explicit KeyboardTranslator(const QString& name);
 
     //KeyboardTranslator(const KeyboardTranslator& other);
 
@@ -289,8 +283,8 @@ public:
      * @param modifiers A combination of modifiers
      * @param state Optional flags which specify the current state of the terminal
      */
-    Entry findEntry(int keyCode , 
-                    Qt::KeyboardModifiers modifiers , 
+    Entry findEntry(int keyCode ,
+                    Qt::KeyboardModifiers modifiers ,
                     States state = NoState) const;
 
     /**
@@ -314,16 +308,21 @@ public:
     QList<Entry> entries() const;
 
 private:
+    // All entries in this translator, indexed by their keycode
+    QMultiHash<int, Entry> _entries;
 
-    QMultiHash<int,Entry> _entries; // entries in this keyboard translation,
-                                                 // entries are indexed according to
-                                                 // their keycode
     QString _name;
     QString _description;
 };
 Q_DECLARE_OPERATORS_FOR_FLAGS(KeyboardTranslator::States)
 Q_DECLARE_OPERATORS_FOR_FLAGS(KeyboardTranslator::Commands)
 
+class FallbackKeyboardTranslator : public KeyboardTranslator
+{
+public:
+    FallbackKeyboardTranslator();
+};
+
 /**
  * Parses the contents of a Keyboard Translator (.keytab) file and
  * returns the entries found in it.
@@ -356,7 +355,7 @@ class KeyboardTranslatorReader
 {
 public:
     /** Constructs a new reader which parses the given @p source */
-    KeyboardTranslatorReader( QIODevice* source );
+    explicit KeyboardTranslatorReader(QIODevice* source);
 
     /**
      * Returns the description text.
@@ -367,7 +366,7 @@ public:
     /** Returns true if there is another entry in the source stream */
     bool hasNextEntry();
     /** Returns the next entry found in the source stream */
-    KeyboardTranslator::Entry nextEntry(); 
+    KeyboardTranslator::Entry nextEntry();
 
     /**
      * Returns true if an error occurred whilst parsing the input or
@@ -381,13 +380,11 @@ public:
      *
      * The condition and result strings are in the same format as in
      */
-    static KeyboardTranslator::Entry createEntry( const QString& condition ,
-                                                  const QString& result );
+    static KeyboardTranslator::Entry createEntry(const QString& condition ,
+            const QString& result);
 private:
-    struct Token
-    {
-        enum Type
-        {
+    struct Token {
+        enum Type {
             TitleKeyword,
             TitleText,
             KeyKeyword,
@@ -400,17 +397,17 @@ private:
     };
     QList<Token> tokenize(const QString&);
     void readNext();
-    bool decodeSequence(const QString& , 
-                                int& keyCode,
-                                Qt::KeyboardModifiers& modifiers,
-                                Qt::KeyboardModifiers& modifierMask,
-                                KeyboardTranslator::States& state,
-                                KeyboardTranslator::States& stateFlags);
+    bool decodeSequence(const QString& ,
+                        int& keyCode,
+                        Qt::KeyboardModifiers& modifiers,
+                        Qt::KeyboardModifiers& modifierMask,
+                        KeyboardTranslator::States& state,
+                        KeyboardTranslator::States& stateFlags);
 
     static bool parseAsModifier(const QString& item , Qt::KeyboardModifier& modifier);
     static bool parseAsStateFlag(const QString& item , KeyboardTranslator::State& state);
     static bool parseAsKeyCode(const QString& item , int& keyCode);
-       static bool parseAsCommand(const QString& text , KeyboardTranslator::Command& command);
+    static bool parseAsCommand(const QString& text , KeyboardTranslator::Command& command);
 
     QIODevice* _source;
     QString _description;
@@ -426,159 +423,108 @@ public:
      * Constructs a new writer which saves data into @p destination.
      * The caller is responsible for closing the device when writing is complete.
      */
-    KeyboardTranslatorWriter(QIODevice* destination);
+    explicit KeyboardTranslatorWriter(QIODevice* destination);
     ~KeyboardTranslatorWriter();
 
     /**
      * Writes the header for the keyboard translator.
      * @param description Description of the keyboard translator.
      */
-    void writeHeader( const QString& description );
+    void writeHeader(const QString& description);
     /** Writes a translator entry. */
-    void writeEntry( const KeyboardTranslator::Entry& entry ); 
+    void writeEntry(const KeyboardTranslator::Entry& entry);
 
 private:
-    QIODevice* _destination;  
+    QIODevice* _destination;
     QTextStream* _writer;
 };
 
-/**
- * Manages the keyboard translations available for use by terminal sessions,
- * see KeyboardTranslator.
- */
-class KONSOLEPRIVATE_EXPORT KeyboardTranslatorManager
+inline int KeyboardTranslator::Entry::keyCode() const
 {
-public:
-    /**
-     * Constructs a new KeyboardTranslatorManager and loads the list of
-     * available keyboard translations.
-     *
-     * The keyboard translations themselves are not loaded until they are
-     * first requested via a call to findTranslator()
-     */
-    KeyboardTranslatorManager();
-    ~KeyboardTranslatorManager();
+    return _keyCode;
+}
+inline void KeyboardTranslator::Entry::setKeyCode(int aKeyCode)
+{
+    _keyCode = aKeyCode;
+}
 
-    /**
-     * Adds a new translator.  If a translator with the same name
-     * already exists, it will be replaced by the new translator.
-     *
-     * TODO: More documentation.
-     */
-    void addTranslator(KeyboardTranslator* translator);
-
-    /**
-     * Deletes a translator.  Returns true on successful deletion or false otherwise.
-     *
-     * TODO: More documentation
-     */
-    bool deleteTranslator(const QString& name);
-
-    /** Returns the default translator for Konsole. */
-    const KeyboardTranslator* defaultTranslator();
-
-    /**
-     * Returns the keyboard translator with the given name or 0 if no translator
-     * with that name exists.
-     *
-     * The first time that a translator with a particular name is requested,
-     * the on-disk .keyboard file is loaded and parsed.
-     */
-    const KeyboardTranslator* findTranslator(const QString& name);
-    /**
-     * Returns a list of the names of available keyboard translators.
-     *
-     * The first time this is called, a search for available
-     * translators is started.
-     */
-    QList<QString> allTranslators();
-
-    /** Returns the global KeyboardTranslatorManager instance. */
-   static KeyboardTranslatorManager* instance();
-
-private:
-    static const QByteArray defaultTranslatorText;
-
-    void findTranslators(); // locate the available translators
-    KeyboardTranslator* loadTranslator(const QString& name); // loads the translator
-                                                             // with the given name
-    KeyboardTranslator* loadTranslator(QIODevice* device,const QString& name);
-
-    bool saveTranslator(const KeyboardTranslator* translator);
-    QString findTranslatorPath(const QString& name);
-
-    QHash<QString,KeyboardTranslator*> _translators; // maps translator-name -> KeyboardTranslator
-                                                     // instance
-    bool _haveLoadedAll;
-};
-
-inline int KeyboardTranslator::Entry::keyCode() const { return _keyCode; }
-inline void KeyboardTranslator::Entry::setKeyCode(int keyCode) { _keyCode = keyCode; }
-
-inline void KeyboardTranslator::Entry::setModifiers( Qt::KeyboardModifiers modifier ) 
-{ 
+inline void KeyboardTranslator::Entry::setModifiers(Qt::KeyboardModifiers modifier)
+{
     _modifiers = modifier;
 }
-inline Qt::KeyboardModifiers KeyboardTranslator::Entry::modifiers() const { return _modifiers; }
+inline Qt::KeyboardModifiers KeyboardTranslator::Entry::modifiers() const
+{
+    return _modifiers;
+}
 
-inline void  KeyboardTranslator::Entry::setModifierMask( Qt::KeyboardModifiers mask ) 
-{ 
-   _modifierMask = mask; 
+inline void  KeyboardTranslator::Entry::setModifierMask(Qt::KeyboardModifiers mask)
+{
+    _modifierMask = mask;
+}
+inline Qt::KeyboardModifiers KeyboardTranslator::Entry::modifierMask() const
+{
+    return _modifierMask;
 }
-inline Qt::KeyboardModifiers KeyboardTranslator::Entry::modifierMask() const { return _modifierMask; }
 
 inline bool KeyboardTranslator::Entry::isNull() const
 {
-    return ( *this == Entry() );
+    return (*this == Entry());
 }
 
-inline void KeyboardTranslator::Entry::setCommand( Command command )
-{ 
-    _command = command; 
+inline void KeyboardTranslator::Entry::setCommand(Command aCommand)
+{
+    _command = aCommand;
+}
+inline KeyboardTranslator::Command KeyboardTranslator::Entry::command() const
+{
+    return _command;
 }
-inline KeyboardTranslator::Command KeyboardTranslator::Entry::command() const { return _command; }
 
-inline void KeyboardTranslator::Entry::setText( const QByteArray& text )
-{ 
-    _text = unescape(text);
+inline void KeyboardTranslator::Entry::setText(const QByteArray& aText)
+{
+    _text = unescape(aText);
 }
 inline int oneOrZero(int value)
 {
     return value ? 1 : 0;
 }
-inline QByteArray KeyboardTranslator::Entry::text(bool expandWildCards,Qt::KeyboardModifiers modifiers) const 
+inline QByteArray KeyboardTranslator::Entry::text(bool expandWildCards,
+        Qt::KeyboardModifiers keyboardModifiers) const
 {
     QByteArray expandedText = _text;
 
-    if (expandWildCards)
-    {
+    if (expandWildCards) {
         int modifierValue = 1;
-        modifierValue += oneOrZero(modifiers & Qt::ShiftModifier);
-        modifierValue += oneOrZero(modifiers & Qt::AltModifier)     << 1;
-        modifierValue += oneOrZero(modifiers & Qt::ControlModifier) << 2;
+        modifierValue += oneOrZero(keyboardModifiers & Qt::ShiftModifier);
+        modifierValue += oneOrZero(keyboardModifiers & Qt::AltModifier)     << 1;
+        modifierValue += oneOrZero(keyboardModifiers & Qt::ControlModifier) << 2;
 
-        for (int i=0;i<_text.length();i++) 
-        {
+        for (int i = 0; i < _text.length(); i++) {
             if (expandedText[i] == '*')
                 expandedText[i] = '0' + modifierValue;
         }
     }
 
-    return expandedText; 
+    return expandedText;
 }
 
-inline void KeyboardTranslator::Entry::setState( States state )
-{ 
-    _state = state; 
+inline void KeyboardTranslator::Entry::setState(States aState)
+{
+    _state = aState;
 }
-inline KeyboardTranslator::States KeyboardTranslator::Entry::state() const { return _state; }
-
-inline void KeyboardTranslator::Entry::setStateMask( States stateMask )
-{ 
-    _stateMask = stateMask; 
+inline KeyboardTranslator::States KeyboardTranslator::Entry::state() const
+{
+    return _state;
 }
-inline KeyboardTranslator::States KeyboardTranslator::Entry::stateMask() const { return _stateMask; }
 
+inline void KeyboardTranslator::Entry::setStateMask(States aStateMask)
+{
+    _stateMask = aStateMask;
+}
+inline KeyboardTranslator::States KeyboardTranslator::Entry::stateMask() const
+{
+    return _stateMask;
+}
 }
 
 Q_DECLARE_METATYPE(Konsole::KeyboardTranslator::Entry)
