@@ -23,42 +23,36 @@
 // Qt
 #include <QtCore/QStringList>
 #include <QtCore/QDir>
+#include <QtGui/QKeyEvent>
 
 // KDE
 #include <KAction>
 #include <KActionCollection>
-#include <KDebug>
 #include <KLocale>
-#include <KWindowSystem>
 #include <KPluginFactory>
 #include <kde_file.h>
 
 // Konsole
-#include "ColorScheme.h"
 #include "EditProfileDialog.h"
 #include "Emulation.h"
-#include "KeyboardTranslator.h"
 #include "ManageProfilesDialog.h"
 #include "Session.h"
 #include "SessionController.h"
 #include "SessionManager.h"
+#include "ProfileManager.h"
 #include "TerminalDisplay.h"
 #include "ViewManager.h"
-#include "MainWindow.h"
-
-#include <config-konsole.h>
 
 using namespace Konsole;
 
 K_PLUGIN_FACTORY(KonsolePartFactory, registerPlugin<Konsole::Part>();)
 K_EXPORT_PLUGIN(KonsolePartFactory("konsole"))
 
-
 Part::Part(QWidget* parentWidget , QObject* parent, const QVariantList&)
- : KParts::ReadOnlyPart(parent)
-  ,_viewManager(0)
-  ,_pluggedController(0)
-  ,_manageProfilesAction(0)
+    : KParts::ReadOnlyPart(parent)
+    , _viewManager(0)
+    , _pluggedController(0)
+    , _manageProfilesAction(0)
 {
     // make sure the konsole catalog is loaded
     KGlobal::locale()->insertCatalog("konsole");
@@ -69,118 +63,125 @@ Part::Part(QWidget* parentWidget , QObject* parent, const QVariantList&)
     createGlobalActions();
 
     // create view widget
-    _viewManager = new ViewManager(this,actionCollection());
-    _viewManager->setNavigationMethod( ViewManager::NoNavigation );
+    _viewManager = new ViewManager(this, actionCollection());
+    _viewManager->setNavigationMethod(ViewManager::NoNavigation);
 
-    connect( _viewManager , SIGNAL(activeViewChanged(SessionController*)) , this ,
-           SLOT(activeViewChanged(SessionController*)) );
-    connect( _viewManager , SIGNAL(empty()) , this , SLOT(terminalExited()) );
-    connect( _viewManager , SIGNAL(newViewRequest()) , this , SLOT(newTab()) );
+    connect(_viewManager, SIGNAL(activeViewChanged(SessionController*)), this ,
+            SLOT(activeViewChanged(SessionController*)));
+    connect(_viewManager, SIGNAL(empty()), this, SLOT(terminalExited()));
+    connect(_viewManager, SIGNAL(newViewRequest()), this, SLOT(newTab()));
 
     _viewManager->widget()->setParent(parentWidget);
 
     setWidget(_viewManager->widget());
     actionCollection()->addAssociatedWidget(_viewManager->widget());
-    foreach (QAction* action, actionCollection()->actions())
+    foreach(QAction* action, actionCollection()->actions()) {
         action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    }
 
     // Enable translucency support.
     _viewManager->widget()->setAttribute(Qt::WA_TranslucentBackground, true);
-    TerminalDisplay::HAVE_TRANSPARENCY = KWindowSystem::compositingActive();
 
     // create basic session
     createSession();
 }
+
 Part::~Part()
 {
-    SessionManager::instance()->saveSettings();
+    ProfileManager::instance()->saveSettings();
 }
+
 void Part::createGlobalActions()
 {
-    _manageProfilesAction = new QAction(i18n("Manage Profiles..."),this);
-    connect(_manageProfilesAction,SIGNAL(triggered()),this,SLOT(showManageProfilesDialog()));
+    _manageProfilesAction = new KAction(i18n("Manage Profiles..."), this);
+    connect(_manageProfilesAction, SIGNAL(triggered()), this, SLOT(showManageProfilesDialog()));
 }
-void Part::setupActionsForSession(SessionController* session)
+
+void Part::setupActionsForSession(SessionController* controller)
 {
-    // TODO: what meaningful operation should be placed here?
-    Q_UNUSED(session);
+    KActionCollection* collection = controller->actionCollection();
+    collection->addAction("manage-profiles", _manageProfilesAction);
 }
+
 bool Part::openFile()
 {
     return false;
 }
+
 void Part::terminalExited()
 {
     deleteLater();
 }
+
 void Part::newTab()
 {
     createSession();
-    showShellInDir( QString() );
 }
+
 Session* Part::activeSession() const
 {
-    if ( _viewManager->activeViewController() )
-    {
-        Q_ASSERT( _viewManager->activeViewController()->session());
+    if (_viewManager->activeViewController()) {
+        Q_ASSERT(_viewManager->activeViewController()->session());
 
         return _viewManager->activeViewController()->session();
-    }
-    else
-    {
+    } else {
         return 0;
     }
 }
-void Part::startProgram( const QString& program,
-                           const QStringList& arguments )
+void Part::startProgram(const QString& program,
+                        const QStringList& arguments)
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
-    if ( !activeSession()->isRunning() )
-    {
-        if ( !program.isEmpty() && !arguments.isEmpty() )
-        {
-            activeSession()->setProgram(program);
-            activeSession()->setArguments(arguments);
-        }
+    // do nothing if the session has already started running
+    if (activeSession()->isRunning())
+        return;
 
-        activeSession()->run();
+    if (!program.isEmpty() && !arguments.isEmpty()) {
+        activeSession()->setProgram(program);
+        activeSession()->setArguments(arguments);
     }
+
+    activeSession()->run();
 }
+
 void Part::openTeletype(int fd)
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
     activeSession()->openTeletype(fd);
 }
-void Part::showShellInDir( const QString& dir )
-{
-    Q_ASSERT( activeSession() );
 
-    if ( !activeSession()->isRunning() )
-    {
-        if ( !dir.isEmpty() )
-            activeSession()->setInitialWorkingDirectory(dir);
-        activeSession()->run();
-    }
-}
-void Part::sendInput( const QString& text )
+void Part::showShellInDir(const QString& dir)
 {
-    Q_ASSERT( activeSession() );
-    activeSession()->emulation()->sendText(text);
+    Q_ASSERT(activeSession());
+
+    // do nothing if the session has already started running
+    if (activeSession()->isRunning())
+        return;
+
+    if (!dir.isEmpty())
+        activeSession()->setInitialWorkingDirectory(dir);
+
+    activeSession()->run();
+}
+
+void Part::sendInput(const QString& text)
+{
+    Q_ASSERT(activeSession());
+    activeSession()->sendText(text);
 }
 
 int Part::terminalProcessId()
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
     return activeSession()->processId();
-
 }
 
 int Part::foregroundProcessId()
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
     if (activeSession()->isForegroundProcessActive()) {
         return activeSession()->foregroundProcessId();
@@ -191,7 +192,7 @@ int Part::foregroundProcessId()
 
 QString Part::foregroundProcessName()
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
     if (activeSession()->isForegroundProcessActive()) {
         return activeSession()->foregroundProcessName();
@@ -200,65 +201,97 @@ QString Part::foregroundProcessName()
     }
 }
 
-Session* Part::createSession(const Profile::Ptr profile)
+QString Part::currentWorkingDirectory() const
 {
-    Session* session = SessionManager::instance()->createSession(profile);
-    _viewManager->createView(session);
+    Q_ASSERT(activeSession());
 
-    return session;
+    return activeSession()->currentWorkingDirectory();
 }
+
+void Part::createSession(const QString& profileName, const QString& directory)
+{
+    Profile::Ptr profile = ProfileManager::instance()->defaultProfile();
+    if (!profileName.isEmpty())
+        profile = ProfileManager::instance()->loadProfile(profileName);
+
+    Q_ASSERT(profile);
+
+    Session* session = SessionManager::instance()->createSession(profile);
+
+    // override the default directory specified in the profile
+    if (!directory.isEmpty() && profile->startInCurrentSessionDir())
+        session->setInitialWorkingDirectory(directory);
+
+    _viewManager->createView(session);
+}
+
+QStringList Part::profileNameList() const
+{
+    return ProfileManager::instance()->availableProfileNames();
+}
+
 void Part::activeViewChanged(SessionController* controller)
 {
-    Q_ASSERT( controller );
-    Q_ASSERT( controller->view() );
+    Q_ASSERT(controller);
+    Q_ASSERT(controller->view());
 
     // remove existing controller
-    if (_pluggedController)
-    {
-        removeChildClient (_pluggedController);
-        disconnect(_pluggedController,SIGNAL(titleChanged(ViewProperties*)),this,
-                    SLOT(activeViewTitleChanged(ViewProperties*)));
+    if (_pluggedController) {
+        removeChildClient(_pluggedController);
+        disconnect(_pluggedController, SIGNAL(titleChanged(ViewProperties*)), this,
+                   SLOT(activeViewTitleChanged(ViewProperties*)));
+        disconnect(_pluggedController, SIGNAL(currentDirectoryChanged(QString)), this,
+                   SIGNAL(currentDirectoryChanged(QString)));
     }
 
     // insert new controller
-    setupActionsForSession(controller);
     insertChildClient(controller);
-    connect(controller,SIGNAL(titleChanged(ViewProperties*)),this,
+    setupActionsForSession(controller);
+
+    connect(controller, SIGNAL(titleChanged(ViewProperties*)), this,
             SLOT(activeViewTitleChanged(ViewProperties*)));
     activeViewTitleChanged(controller);
+    connect(controller, SIGNAL(currentDirectoryChanged(QString)), this,
+            SIGNAL(currentDirectoryChanged(QString)));
 
     const char* displaySignal = SIGNAL(overrideShortcutCheck(QKeyEvent*,bool&));
     const char* partSlot = SLOT(overrideTerminalShortcut(QKeyEvent*,bool&));
 
-    disconnect(controller->view(),displaySignal,this,partSlot);
-    connect(controller->view(),displaySignal,this,partSlot);
+    disconnect(controller->view(), displaySignal, this, partSlot);
+    connect(controller->view(), displaySignal, this, partSlot);
+
+    // set the current session's search bar
+    controller->setSearchBar(_viewManager->searchBar());
 
     _pluggedController = controller;
 }
+
 void Part::overrideTerminalShortcut(QKeyEvent* event, bool& override)
 {
     // Shift+Insert is commonly used as the alternate shorcut for
     // pasting in KDE apps(including konsole), so it deserves some
     // special treatment.
-    if ( (event->modifiers() & Qt::ShiftModifier) &&
-         (event->key() == Qt::Key_Insert) )
-    {
+    if ((event->modifiers() & Qt::ShiftModifier) &&
+            (event->key() == Qt::Key_Insert)) {
         override = false;
         return;
     }
 
     // override all shortcuts in the embedded terminal by default
     override = true;
-    emit overrideShortcut(event,override);
+    emit overrideShortcut(event, override);
 }
+
 void Part::activeViewTitleChanged(ViewProperties* properties)
 {
     emit setWindowCaption(properties->title());
 }
+
 void Part::showManageProfilesDialog()
 {
     showManageProfilesDialog(_viewManager->widget());
 }
+
 void Part::showManageProfilesDialog(QWidget* parent)
 {
     ManageProfilesDialog* dialog = new ManageProfilesDialog(parent);
@@ -266,47 +299,49 @@ void Part::showManageProfilesDialog(QWidget* parent)
     dialog->setShortcutEditorVisible(false);
     dialog->show();
 }
+
 void Part::showEditCurrentProfileDialog(QWidget* parent)
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
     EditProfileDialog* dialog = new EditProfileDialog(parent);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
-    dialog->setProfile( SessionManager::instance()->sessionProfile(activeSession()) );
+    dialog->setProfile(SessionManager::instance()->sessionProfile(activeSession()));
     dialog->show();
 }
+
 void Part::changeSessionSettings(const QString& text)
 {
+    Q_ASSERT(activeSession());
+
     // send a profile change command, the escape code format
     // is the same as the normal X-Term commands used to change the window title or icon,
     // but with a magic value of '50' for the parameter which specifies what to change
-    Q_ASSERT( activeSession() );
-    QByteArray buffer;
-    buffer.append("\033]50;").append(text.toUtf8()).append('\a');
+    QString command = QString("\033]50;%1\a").arg(text);
 
-    activeSession()->emulation()->receiveData(buffer.constData(),buffer.length());
+    sendInput(command);
 }
 
 // Konqueror integration
-bool Part::openUrl( const KUrl & _url )
+bool Part::openUrl(const KUrl& aUrl)
 {
-    if ( url() == _url ) {
+    if (url() == aUrl) {
         emit completed();
         return true;
     }
 
-    setUrl( _url );
-    emit setWindowCaption( _url.pathOrUrl() );
+    setUrl(aUrl);
+    emit setWindowCaption(aUrl.pathOrUrl());
     //kdDebug() << "Set Window Caption to " << url.pathOrUrl();
-    emit started( 0 );
+    emit started(0);
 
-    if ( _url.isLocalFile() /*&& b_openUrls*/ ) {
+    if (aUrl.isLocalFile() /*&& b_openUrls*/) {
         KDE_struct_stat buff;
-        KDE::stat( QFile::encodeName( _url.path() ), &buff );
-        QString text = ( S_ISDIR( buff.st_mode ) ? _url.path() : _url.directory() );
-        showShellInDir( text );
+        KDE::stat(QFile::encodeName(aUrl.path()), &buff);
+        QString text = (S_ISDIR(buff.st_mode) ? aUrl.path() : aUrl.directory());
+        showShellInDir(text);
     } else {
-        showShellInDir( QDir::homePath() );
+        showShellInDir(QDir::homePath());
     }
 
     emit completed();
@@ -315,15 +350,12 @@ bool Part::openUrl( const KUrl & _url )
 
 void Part::setMonitorSilenceEnabled(bool enabled)
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
-    if (enabled)
-    {
+    if (enabled) {
         activeSession()->setMonitorSilence(true);
         connect(activeSession(), SIGNAL(stateChanged(int)), this, SLOT(sessionStateChanged(int)), Qt::UniqueConnection);
-    }
-    else
-    {
+    } else {
         activeSession()->setMonitorSilence(false);
         disconnect(activeSession(), SIGNAL(stateChanged(int)), this, SLOT(sessionStateChanged(int)));
     }
@@ -331,15 +363,12 @@ void Part::setMonitorSilenceEnabled(bool enabled)
 
 void Part::setMonitorActivityEnabled(bool enabled)
 {
-    Q_ASSERT( activeSession() );
+    Q_ASSERT(activeSession());
 
-    if (enabled)
-    {
+    if (enabled) {
         activeSession()->setMonitorActivity(true);
         connect(activeSession(), SIGNAL(stateChanged(int)), this, SLOT(sessionStateChanged(int)), Qt::UniqueConnection);
-    }
-    else
-    {
+    } else {
         activeSession()->setMonitorActivity(false);
         disconnect(activeSession(), SIGNAL(stateChanged(int)), this, SLOT(sessionStateChanged(int)));
     }
