@@ -31,6 +31,7 @@
 #include "konsole_export.h"
 #include "ScreenWindow.h"
 #include "ColorScheme.h"
+#include "Enumeration.h"
 
 class QDrag;
 class QDragEnterEvent;
@@ -44,13 +45,9 @@ class QScrollBar;
 class QShowEvent;
 class QHideEvent;
 class QTimerEvent;
-class QWidget;
-
-class KMenu;
 
 namespace Konsole
 {
-
 class FilterChain;
 class TerminalImageFilterChain;
 class SessionController;
@@ -66,11 +63,11 @@ class SessionController;
  */
 class KONSOLEPRIVATE_EXPORT TerminalDisplay : public QWidget
 {
-   Q_OBJECT
+    Q_OBJECT
 
 public:
     /** Constructs a new terminal display widget with the specified parent. */
-    TerminalDisplay(QWidget* parent=0);
+    explicit TerminalDisplay(QWidget* parent = 0);
     virtual ~TerminalDisplay();
 
     /** Returns the terminal color palette used by the display. */
@@ -94,23 +91,11 @@ public:
     /** Sets the background picture */
     void setWallpaper(ColorSchemeWallpaper::Ptr p);
 
-    /**
-     * This enum describes the location where the scroll bar is positioned in the display widget.
-     */
-    enum ScrollBarPosition
-    {
-        /** Show the scroll bar on the left side of the display. */
-        ScrollBarLeft = 0,
-        /** Show the scroll bar on the right side of the display. */
-        ScrollBarRight = 1,
-        /** Do not show the scroll bar. */
-        ScrollBarHidden = 2
-    };
     /**
      * Specifies whether the terminal display has a vertical scroll bar, and if so whether it
      * is shown on the left or right side of the display.
      */
-    void setScrollBarPosition(ScrollBarPosition position);
+    void setScrollBarPosition(Enum::ScrollBarPositionEnum position);
 
     /**
      * Sets the current position and range of the display's scroll bar.
@@ -158,65 +143,49 @@ public:
     /** Specifies whether or not the cursor can blink. */
     void setBlinkingCursorEnabled(bool blink);
     /** Returns true if the cursor is allowed to blink or false otherwise. */
-    bool blinkingCursorEnabled() const { return _allowBlinkingCursor; }
+    bool blinkingCursorEnabled() const {
+        return _allowBlinkingCursor;
+    }
 
     /** Specifies whether or not text can blink. */
     void setBlinkingTextEnabled(bool blink);
 
-    void setCtrlDrag(bool enable) { _ctrlDrag=enable; }
-    bool ctrlDrag() const { return _ctrlDrag; }
+    void setCtrlDrag(bool enable) {
+        _ctrlDrag = enable;
+    }
+    bool ctrlDrag() const {
+        return _ctrlDrag;
+    }
 
-    /**
-     *  This enum describes the methods for selecting text when
-      *  the user triple-clicks within the display.
-      */
-    enum TripleClickMode
-    {
-        /** Select the whole line underneath the cursor. */
-        SelectWholeLine,
-        /** Select from the current cursor position to the end of the line. */
-        SelectForwardsFromCursor
-    };
     /** Sets how the text is selected when the user triple clicks within the display. */
-    void setTripleClickMode(TripleClickMode mode) { _tripleClickMode = mode; }
+    void setTripleClickMode(Enum::TripleClickModeEnum mode) {
+        _tripleClickMode = mode;
+    }
     /** See setTripleClickSelectionMode() */
-    TripleClickMode tripleClickMode() const { return _tripleClickMode; }
+    Enum::TripleClickModeEnum tripleClickMode() const {
+        return _tripleClickMode;
+    }
 
     /**
      * Specifies whether links and email addresses should be underlined when
      * hovered by the mouse. Defaults to true.
      */
-    void setUnderlineLinks(bool value) { _underlineLinks = value; }
+    void setUnderlineLinks(bool value) {
+        _underlineLinks = value;
+    }
     /**
      * Returns true if links and email addresses should be underlined when
      * hovered by the mouse.
      */
-    bool getUnderlineLinks() const { return _underlineLinks; }
+    bool getUnderlineLinks() const {
+        return _underlineLinks;
+    }
 
     void setLineSpacing(uint);
     uint lineSpacing() const;
 
     void setSessionController(SessionController* controller);
 
-    /**
-     * This enum describes the available shapes for the keyboard cursor.
-     * See setKeyboardCursorShape()
-     */
-    enum KeyboardCursorShape
-    {
-        /** A rectangular block which covers the entire area of the cursor character. */
-        BlockCursor,
-        /**
-         * A single flat line which occupies the space at the bottom of the cursor
-         * character's area.
-         */
-        UnderlineCursor,
-        /**
-         * An cursor shaped like the capital letter 'I', similar to the IBeam
-         * cursor used in Qt/KDE text editors.
-         */
-        IBeamCursor
-    };
     /**
      * Sets the shape of the keyboard cursor.  This is the cursor drawn
      * at the position in the terminal where keyboard input will appear.
@@ -227,11 +196,11 @@ public:
      *
      * Defaults to BlockCursor
      */
-    void setKeyboardCursorShape(KeyboardCursorShape shape);
+    void setKeyboardCursorShape(Enum::CursorShapeEnum shape);
     /**
      * Returns the shape of the keyboard cursor.  See setKeyboardCursorShape()
      */
-    KeyboardCursorShape keyboardCursorShape() const;
+    Enum::CursorShapeEnum keyboardCursorShape() const;
 
     /**
      * Sets the color used to draw the keyboard cursor.
@@ -239,14 +208,14 @@ public:
      * The keyboard cursor defaults to using the foreground color of the character
      * underneath it.
      *
-     * @param useForegroundColor If true, the cursor color will change to match
-     * the foreground color of the character underneath it as it is moved, in this
-     * case, the @p color parameter is ignored and the color of the character
-     * under the cursor is inverted to ensure that it is still readable.
-     * @param color The color to use to draw the cursor.  This is only taken into
-     * account if @p useForegroundColor is false.
+     * @param color By default, the widget uses the color of the
+     * character under the cursor to draw the cursor, and inverts the
+     * color of that character to make sure it is still readable. If @p
+     * color is a valid QColor, the widget uses that color to draw the
+     * cursor. If @p color is not an valid QColor, the widget falls back
+     * to the default behavior.
      */
-    void setKeyboardCursorColor(bool useForegroundColor , const QColor& color);
+    void setKeyboardCursorColor(const QColor& color);
 
     /**
      * Returns the color of the keyboard cursor, or an invalid color if the keyboard
@@ -261,7 +230,9 @@ public:
      * This will depend upon the height of the widget and the current font.
      * See fontHeight()
      */
-    int  lines() const { return _lines; }
+    int  lines() const {
+        return _lines;
+    }
     /**
      * Returns the number of characters of text which can be displayed on
      * each line in the widget.
@@ -269,17 +240,23 @@ public:
      * This will depend upon the width of the widget and the current font.
      * See fontWidth()
      */
-    int  columns() const { return _columns; }
+    int  columns() const {
+        return _columns;
+    }
 
     /**
      * Returns the height of the characters in the font used to draw the text in the display.
      */
-    int  fontHeight() const { return _fontHeight; }
+    int  fontHeight() const {
+        return _fontHeight;
+    }
     /**
      * Returns the width of the characters in the display.
      * This assumes the use of a fixed-width font.
      */
-    int  fontWidth() const { return _fontWidth; }
+    int  fontWidth() const {
+        return _fontWidth;
+    }
 
     void setSize(int columns, int lines);
     void setFixedSize(int columns, int lines);
@@ -305,7 +282,9 @@ public:
      *
      * @see setWordCharacters()
      */
-    QString wordCharacters() const { return _wordCharacters; }
+    QString wordCharacters() const {
+        return _wordCharacters;
+    }
 
     /**
      * Sets the type of effect used to alert the user when a 'bell' occurs in the
@@ -318,30 +297,10 @@ public:
     /**
      * Returns the type of effect used to alert the user when a 'bell' occurs in
      * the terminal session.
-     * 
+     *
      * See setBellMode()
      */
-    int bellMode() const { return _bellMode; }
-
-    /**
-     * This enum describes the different types of sounds and visual effects which
-     * can be used to alert the user when a 'bell' occurs in the terminal
-     * session.
-     */
-    enum BellMode
-    {
-        /** A system beep. */
-        SystemBeepBell=0,
-        /**
-         * KDE notification.  This may play a sound, show a passive popup
-         * or perform some other action depending on the user's settings.
-         */
-        NotifyBell=1,
-        /** A silent, visual bell (eg. inverting the display's colors briefly) */
-        VisualBell=2,
-        /** No bell effects */
-        NoBell=3
-    };
+    int bellMode() const;
 
     /** Play a visual bell for prompt or warning. */
     void visualBell();
@@ -353,7 +312,9 @@ public:
     virtual void setFont(const QFont &);
 
     /** Returns the font used to draw characters in the display */
-    QFont getVTFont() { return font(); }
+    QFont getVTFont() {
+        return font();
+    }
 
     /**
      * Sets the font used to draw the display.  Has no effect if @p font
@@ -361,45 +322,63 @@ public:
      */
     void setVTFont(const QFont& font);
 
+    /** Increases the font size */
+    void increaseFontSize();
+
+    /** Decreases the font size */
+    void decreaseFontSize();
+
     /**
      * Specified whether anti-aliasing of text in the terminal display
      * is enabled or not.  Defaults to enabled.
      */
-    void setAntialias( bool antialias ) { _antialiasText = antialias; }
+    void setAntialias(bool value) {
+        _antialiasText = value;
+    }
     /**
      * Returns true if anti-aliasing of text in the terminal is enabled.
      */
-    bool antialias() const { return _antialiasText;   }
+    bool antialias() const {
+        return _antialiasText;
+    }
 
     /**
      * Specifies whether characters with intense colors should be rendered
      * as bold. Defaults to true.
      */
-    void setBoldIntense(bool value) { _boldIntense = value; }
+    void setBoldIntense(bool value) {
+        _boldIntense = value;
+    }
     /**
      * Returns true if characters with intense colors are rendered in bold.
      */
-    bool getBoldIntense() const { return _boldIntense; }
+    bool getBoldIntense() const {
+        return _boldIntense;
+    }
 
     /**
      * Sets whether or not the current height and width of the
      * terminal in lines and columns is displayed whilst the widget
      * is being resized.
      */
-    void setShowTerminalSizeHint(bool on) { _showTerminalSizeHint=on; }
+    void setShowTerminalSizeHint(bool on) {
+        _showTerminalSizeHint = on;
+    }
     /**
      * Returns whether or not the current height and width of
      * the terminal in lines and columns is displayed whilst the widget
      * is being resized.
      */
-    bool showTerminalSizeHint() const { return _showTerminalSizeHint; }
+    bool showTerminalSizeHint() const {
+        return _showTerminalSizeHint;
+    }
 
     /**
      * Sets the status of the BiDi rendering inside the terminal display.
      * Defaults to disabled.
      */
     void setBidiEnabled(bool set) {
-        _bidiEnabled=set;
+        _bidiEnabled = set;
         // See bug 280896 for more info
 #if QT_VERSION >= 0x040800
         if (_bidiEnabled) {
@@ -412,7 +391,9 @@ public:
     /**
      * Returns the status of the BiDi rendering in this widget.
      */
-    bool isBidiEnabled() const { return _bidiEnabled; }
+    bool isBidiEnabled() const {
+        return _bidiEnabled;
+    }
 
     /**
      * Sets the terminal screen section which is displayed in this widget.
@@ -422,45 +403,49 @@ public:
      * In terms of the model-view paradigm, the ScreenWindow is the model which is rendered
      * by the TerminalDisplay.
      */
-    void setScreenWindow( ScreenWindow* window );
+    void setScreenWindow(ScreenWindow* window);
     /** Returns the terminal screen section which is displayed in this widget.  See setScreenWindow() */
     ScreenWindow* screenWindow() const;
 
-    static void setXSelection(const QString& text);
-
-    static bool HAVE_TRANSPARENCY;
-
 public slots:
     /**
      * Scrolls current ScreenWindow
      *
      * it's needed for proper handling scroll commands in the Vt102Emulation class
      */
-    void scrollScreenWindow( enum ScreenWindow::RelativeScrollMode mode , int amount );
+    void scrollScreenWindow(enum ScreenWindow::RelativeScrollMode mode , int amount);
 
     /**
      * Causes the terminal display to fetch the latest character image from the associated
      * terminal screen ( see setScreenWindow() ) and redraw the display.
      */
-    void updateImage(); 
+    void updateImage();
     /**
      * Causes the terminal display to fetch the latest line status flags from the
      * associated terminal screen ( see setScreenWindow() ).
      */
     void updateLineProperties();
 
-    /** Copies the selected text to the clipboard. */
+    void setAutoCopySelectedText(bool enabled);
+
+    void setMiddleClickPasteMode(Enum::MiddleClickPasteModeEnum mode);
+
+    /** Copies the selected text to the X11 Selection. */
+    void copyToX11Selection();
+
+    /** Copies the selected text to the system clipboard. */
     void copyToClipboard();
+
     /**
      * Pastes the content of the clipboard into the
      * display.
      */
-    void pasteFromClipboard();
+    void pasteFromClipboard(bool appendEnter = false);
     /**
-     * Pastes the content of the X selection into the
+     * Pastes the content of the X11 selection into the
      * display.
      */
-    void pasteFromXSelection();
+    void pasteFromX11Selection(bool appendEnter = false);
 
     /**
        * Changes whether the flow control warning box should be shown when the flow control
@@ -471,8 +456,9 @@ public slots:
      * Returns true if the flow control warning box is enabled.
      * See outputSuspended() and setFlowControlWarningEnabled()
      */
-    bool flowControlWarningEnabled() const
-    { return _flowControlWarningEnabled; }
+    bool flowControlWarningEnabled() const {
+        return _flowControlWarningEnabled;
+    }
 
     /**
      * Causes the widget to display or hide a message informing the user that terminal
@@ -521,11 +507,6 @@ public slots:
      */
     void setForegroundColor(const QColor& color);
 
-    /**
-     * Called from the drag'n'drop popup. Causes the dropped URLs to be pasted as text.
-     */
-    void dropMenuPasteTriggered();
-
 signals:
 
     /**
@@ -561,31 +542,33 @@ signals:
      *
      * @p override is set to false by default and the shortcut will be triggered as normal.
      */
-    void overrideShortcutCheck(QKeyEvent* keyEvent,bool& override);
+    void overrideShortcutCheck(QKeyEvent* keyEvent, bool& override);
 
-   void sendStringToEmu(const char*);
+    void sendStringToEmu(const char*);
 
 protected:
-    virtual bool event( QEvent* event);
+    virtual bool event(QEvent* event);
 
-    virtual void paintEvent( QPaintEvent* event);
+    virtual void paintEvent(QPaintEvent* event);
 
     virtual void showEvent(QShowEvent* event);
     virtual void hideEvent(QHideEvent* event);
     virtual void resizeEvent(QResizeEvent* event);
 
-    virtual void fontChange(const QFont& );
+    virtual void contextMenuEvent(QContextMenuEvent* event);
+
+    virtual void fontChange(const QFont&);
     virtual void focusInEvent(QFocusEvent* event);
     virtual void focusOutEvent(QFocusEvent* event);
     virtual void keyPressEvent(QKeyEvent* event);
     virtual void mouseDoubleClickEvent(QMouseEvent* event);
-    virtual void mousePressEvent( QMouseEvent* event);
-    virtual void mouseReleaseEvent( QMouseEvent* event);
-    virtual void mouseMoveEvent( QMouseEvent* event);
-    virtual void extendSelection( const QPoint& pos );
-    virtual void wheelEvent( QWheelEvent* event);
+    virtual void mousePressEvent(QMouseEvent* event);
+    virtual void mouseReleaseEvent(QMouseEvent* event);
+    virtual void mouseMoveEvent(QMouseEvent* event);
+    virtual void extendSelection(const QPoint& pos);
+    virtual void wheelEvent(QWheelEvent* event);
 
-    virtual bool focusNextPrevChild( bool next );
+    virtual bool focusNextPrevChild(bool next);
 
     // drag and drop
     virtual void dragEnterEvent(QDragEnterEvent* event);
@@ -594,9 +577,9 @@ protected:
     enum DragState { diNone, diPending, diDragging };
 
     struct DragInfo {
-      DragState       state;
-      QPoint          start;
-      QDrag*          dragObject;
+        DragState       state;
+        QPoint          start;
+        QDrag*          dragObject;
     } _dragInfo;
 
     // classifies the 'ch' into one of three categories
@@ -612,8 +595,8 @@ protected:
     void mouseTripleClickEvent(QMouseEvent* event);
 
     // reimplemented
-    virtual void inputMethodEvent ( QInputMethodEvent* event );
-    virtual QVariant inputMethodQuery( Qt::InputMethodQuery query ) const;
+    virtual void inputMethodEvent(QInputMethodEvent* event);
+    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
 
 protected slots:
 
@@ -621,17 +604,20 @@ protected slots:
     void blinkTextEvent();
     void blinkCursorEvent();
 
-    //Re-enables bell noises and visuals.  Used to disable further bells for a short period of time
-    //after emitting the first in a sequence of bell events.
-    void enableBell();
-
 private slots:
 
-    void swapColorTable();
+    void unmaskBell();
+    void swapFGBGColors();
     void tripleClickTimeout();  // resets possibleTripleClick
 
-private:
+    /**
+     * Called from the drag'n'drop popup. Causes the dropped URLs to be pasted as text.
+     */
+    void dropMenuPasteActionTriggered();
 
+    void dropMenuCdActionTriggered();
+
+private:
     // -- Drawing helpers --
 
     // divides the part of the display specified by 'rect' into
@@ -640,8 +626,8 @@ private:
     void drawContents(QPainter& painter, const QRect& rect);
     // draws a section of text, all the text in this section
     // has a common color and style
-    void drawTextFragment(QPainter& painter, const QRect& rect, 
-                          const QString& text, const Character* style); 
+    void drawTextFragment(QPainter& painter, const QRect& rect,
+                          const QString& text, const Character* style);
     // draws the background for a text fragment
     // if useOpacitySetting is true then the color's alpha value will be set to
     // the display's transparency (set with setOpacity()), otherwise the background
@@ -649,13 +635,13 @@ private:
     void drawBackground(QPainter& painter, const QRect& rect, const QColor& color,
                         bool useOpacitySetting);
     // draws the cursor character
-    void drawCursor(QPainter& painter, const QRect& rect , const QColor& foregroundColor, 
-                                       const QColor& backgroundColor , bool& invertColors);
+    void drawCursor(QPainter& painter, const QRect& rect , const QColor& foregroundColor,
+                    const QColor& backgroundColor , bool& invertColors);
     // draws the characters or line graphics in a text fragment
-    void drawCharacters(QPainter& painter, const QRect& rect,  const QString& text, 
-                                           const Character* style, bool invertCharacterColor);
+    void drawCharacters(QPainter& painter, const QRect& rect,  const QString& text,
+                        const Character* style, bool invertCharacterColor);
     // draws a string of line graphics
-    void drawLineCharString(QPainter& painter, int x, int y, 
+    void drawLineCharString(QPainter& painter, int x, int y,
                             const QString& str, const Character* attributes);
 
     // draws the preedit string for input methods
@@ -668,7 +654,7 @@ private:
 
     // maps a point on the widget to the position ( ie. line and column )
     // of the character at that point.
-    void getCharacterPosition(const QPoint& widgetPoint,int& line,int& column) const;
+    void getCharacterPosition(const QPoint& widgetPoint, int& line, int& column) const;
 
     // the area where the preedit string for input methods will be draw
     QRect preeditRect() const;
@@ -704,13 +690,15 @@ private:
 
     bool handleShortcutOverrideEvent(QKeyEvent* event);
 
-    void doPaste(bool useXselection,bool appendReturn);
+    void doPaste(QString text, bool appendReturn);
+
+    void processMidButtonClick(QMouseEvent* event);
 
     // the window onto the terminal screen which this display
     // is currently showing.
     QPointer<ScreenWindow> _screenWindow;
 
-    bool _allowBell;
+    bool _bellMasked;
 
     QGridLayout* _gridLayout;
 
@@ -727,17 +715,17 @@ private:
     int _columns;    // the number of columns that can be displayed in the widget
 
     int _usedLines;  // the number of lines that are actually being used, this will be less
-                    // than 'lines' if the character image provided with setImage() is smaller
-                    // than the maximum image size which can be displayed
+    // than 'lines' if the character image provided with setImage() is smaller
+    // than the maximum image size which can be displayed
 
     int _usedColumns; // the number of columns that are actually being used, this will be less
-                     // than 'columns' if the character image provided with setImage() is smaller
-                     // than the maximum image size which can be displayed
+    // than 'columns' if the character image provided with setImage() is smaller
+    // than the maximum image size which can be displayed
 
     int _contentHeight;
     int _contentWidth;
     Character* _image; // [lines][columns]
-               // only the area [usedLines][usedColumns] in the image contains valid data
+    // only the area [usedLines][usedColumns] in the image contains valid data
 
     int _imageSize;
     QVector<LineProperty> _lineProperties;
@@ -759,15 +747,18 @@ private:
     bool    _preserveLineBreaks;
     bool    _columnSelectionMode;
 
+    bool _autoCopySelectedText;
+    Enum::MiddleClickPasteModeEnum _middleClickPasteMode;
+
     QScrollBar* _scrollBar;
-    ScrollBarPosition _scrollbarLocation;
+    Enum::ScrollBarPositionEnum _scrollbarLocation;
     QString     _wordCharacters;
     int         _bellMode;
 
     bool _allowBlinkingText;  // allow text to blink
     bool _allowBlinkingCursor;  // allow cursor to blink
-    bool _textBlinking;   // hide text in paintEvent
-    bool _cursorBlinking;     // hide cursor in paintEvent
+    bool _textBlinking;   // text is blinkingi, hide it when drawing
+    bool _cursorBlinking;     // cursor is blinking, hide it whe drawing
     bool _hasTextBlinker; // has characters to blink
     QTimer* _blinkTextTimer;
     QTimer* _blinkCursorTimer;
@@ -777,9 +768,9 @@ private:
 
     bool _ctrlDrag; // require Ctrl key for drag selected text
 
-    TripleClickMode _tripleClickMode;
+    Enum::TripleClickModeEnum _tripleClickMode;
     bool _possibleTripleClick;  // is set in mouseDoubleClickEvent and deleted
-                               // after QApplication::doubleClickInterval() delay
+    // after QApplication::doubleClickInterval() delay
 
     QLabel* _resizeWidget;
     QTimer* _resizeTimer;
@@ -788,12 +779,10 @@ private:
 
     //widgets related to the warning message that appears when the user presses Ctrl+S to suspend
     //terminal output - informing them what has happened and how to resume output
-    QLabel* _outputSuspendedLabel; 
+    QLabel* _outputSuspendedLabel;
 
     uint _lineSpacing;
 
-    bool _colorsInverted; // true during visual bell
-
     QSize _size;
 
     QRgb _blendColor;
@@ -805,15 +794,13 @@ private:
     TerminalImageFilterChain* _filterChain;
     QRegion _mouseOverHotspotArea;
 
-    KeyboardCursorShape _cursorShape;
+    Enum::CursorShapeEnum _cursorShape;
 
-    // custom cursor color.  if this is invalid then the foreground
+    // cursor color. If it is invalid (by default) then the foreground
     // color of the character under the cursor is used
-    QColor _cursorColor;  
+    QColor _cursorColor;
 
-
-    struct InputMethodData
-    {
+    struct InputMethodData {
         QString preeditString;
         QRect previousPreeditRect;
     };
@@ -823,32 +810,32 @@ private:
 
     //the delay in milliseconds between redrawing blinking text
     static const int TEXT_BLINK_DELAY = 500;
+
+    //the duration of the size hint in milliseconds
+    static const int SIZE_HINT_DURATION = 1000;
+
     static const int DEFAULT_LEFT_MARGIN = 1;
     static const int DEFAULT_TOP_MARGIN = 1;
 
     SessionController* _sessionController;
-
-public:
-    static void setTransparencyEnabled(bool enable)
-    {
-        HAVE_TRANSPARENCY = enable;
-    }
+    friend class TerminalDisplayAccessible;
 };
 
 class AutoScrollHandler : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    AutoScrollHandler(QWidget* parent);
+    explicit AutoScrollHandler(QWidget* parent);
 protected:
     virtual void timerEvent(QTimerEvent* event);
-    virtual bool eventFilter(QObject* watched,QEvent* event);
+    virtual bool eventFilter(QObject* watched, QEvent* event);
 private:
-    QWidget* widget() const { return static_cast<QWidget*>(parent()); }
+    QWidget* widget() const {
+        return static_cast<QWidget*>(parent());
+    }
     int _timerId;
 };
-
 }
 
 #endif // TERMINALDISPLAY_H
